class aes::squid_filter {

  package { "squid" :
    ensure => "present",
  }

  file { '/etc/squid/squid.conf':
    ensure => file,
    mode   => '0644',
    owner  => root,
    group  => root,
    content => file("${module_name}/squid/squid.conf"),
  }
  
  file { '/usr/libexec/squid/helpers':
    ensure => directory,
    recurse => true,
    purge => true,
    force => true,
    owner  => squid,
    group  => squid,
    mode => '0644',
    source => "puppet:///modules/${module_name}/squid/helpers",
  }

  file { '/usr/libexec/squid/helpers/squid-url-rewrite.py':
    ensure => file,
    owner  => squid,
    group  => squid,
    mode => '0755',
    source => "puppet:///modules/${module_name}/squid/helpers/squid-url-rewrite.py",
  }

  file { '/var/cache/squid' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  file { '/var/log/squid' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  file { '/var/lib/ssl_db' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  exec { '/usr/lib64/squid/ssl_crtd -c -s /var/lib/ssl_db' : 
    user => "squid",
    group => "squid",
    creates => '/var/lib/ssl_db/certs',
  }

  service { "squid" : 
    ensure => "running",
  }

}
